/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03404
 |       DRUG ABUSE TREATMENT OUTCOME STUDY--ADOLESCENT (DATOS-A),
 |                       1993-1995: [UNITED STATES]
 |         (DATASET 0009:  12-MONTH FOLLOW-UP URINE RESULT DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03404-0009-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study--Adolescent (DATOS-A), 1993-1995: [United States], Dataset 0009"

#delimit ;
label define CASEID    -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE" ;
label define AMPH      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define BARB      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define BENZ      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define CANN      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define COC       -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define METH      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define OP        -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;
label define PHEN      -9 "LEGITIMATE NONRESPONSE" -8 "MISSING" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "RESPONSE ILLEGIBLE"
                       0 "NEGATIVE FOR DRUG" 1 "POSITIVE FOR DRUG" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace AMPH = . if (AMPH <= -1 )
replace BARB = . if (BARB <= -1 )
replace BENZ = . if (BENZ <= -1 )
replace CANN = . if (CANN <= -1 )
replace COC = . if (COC <= -1 )
replace METH = . if (METH <= -1 )
replace OP = . if (OP <= -1 )
replace PHEN = . if (PHEN <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

